@@ -11,7 +11,7 @@ def greet(name):
     
 def greet_main():
     if len(sys.argv) > 1:
-        name = sys.argv[1]
+        name = ' '.join(sys.argv[1:])
     else:
         name = 'unknown human'
     greet(name)
